@@ -29,6 +29,10 @@ use std::fs::{
 	File,
 };
 use std::io;
+use std::time::{
+	SystemTime,
+	UNIX_EPOCH,
+};
 
 /// Checks for a new version on crates.io
 #[cfg(feature = "update-informer")]
@@ -132,9 +136,9 @@ pub fn run(mut args: Opt) -> Result<()> {
 				.expect("Incorrect config value for 'sort_commits'");
 		}
 	}
-	if !args.date_order {
-		if let Some(date_order) = config.git.date_order {
-			args.date_order = date_order;
+	if !args.topo_order {
+		if let Some(topo_order) = config.git.topo_order {
+			args.topo_order = topo_order;
 		}
 	}
 
@@ -143,7 +147,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 		Repository::init(args.repository.clone().unwrap_or(env::current_dir()?))?;
 
 	// Parse tags.
-	let mut tags = repository.tags(&config.git.tag_pattern, args.date_order)?;
+	let mut tags = repository.tags(&config.git.tag_pattern, args.topo_order)?;
 
 	// Skip tags.
 	config.git.skip_tags = config.git.skip_tags.filter(|r| !r.as_str().is_empty());
@@ -181,7 +185,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 	let mut commit_range = args.range;
 	if args.unreleased {
 		if let Some(last_tag) = tags.last().map(|(k, _)| k) {
-			commit_range = Some(format!("{}..HEAD", last_tag));
+			commit_range = Some(format!("{last_tag}..HEAD"));
 		}
 	} else if args.latest || args.current {
 		if tags.len() < 2 {
@@ -190,7 +194,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 				commits.last().map(|c| c.id().to_string()),
 				tags.get_index(0).map(|(k, _)| k),
 			) {
-				commit_range = Some(format!("{}..{}", tag1, tag2));
+				commit_range = Some(format!("{tag1}..{tag2}"));
 			}
 		} else {
 			let mut tag_index = tags.len() - 2;
@@ -207,7 +211,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 						None => {
 							return Err(Error::ChangelogError(String::from(
 								"No suitable tags found. Maybe run with \
-								 '--date-order'?",
+								 '--topo-order'?",
 							)));
 						}
 					}
@@ -221,7 +225,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 				tags.get_index(tag_index).map(|(k, _)| k),
 				tags.get_index(tag_index + 1).map(|(k, _)| k),
 			) {
-				commit_range = Some(format!("{}..{}", tag1, tag2));
+				commit_range = Some(format!("{tag1}..{tag2}"));
 			}
 		}
 	}
@@ -232,14 +236,14 @@ pub fn run(mut args: Opt) -> Result<()> {
 	}
 
 	// Update tags.
-	if let Some(tag) = args.tag {
+	if let Some(ref tag) = args.tag {
 		if let Some(commit_id) = commits.first().map(|c| c.id().to_string()) {
 			match tags.get(&commit_id) {
 				Some(tag) => {
 					warn!("There is already a tag ({}) for {}", tag, commit_id)
 				}
 				None => {
-					tags.insert(commit_id, tag);
+					tags.insert(commit_id, tag.to_string());
 				}
 			}
 		}
@@ -260,7 +264,14 @@ pub fn run(mut args: Opt) -> Result<()> {
 		if let Some(tag) = tags.get(&commit_id) {
 			releases[release_index].version = Some(tag.to_string());
 			releases[release_index].commit_id = Some(commit_id);
-			releases[release_index].timestamp = git_commit.time().seconds();
+			releases[release_index].timestamp = if args.tag.as_deref() == Some(tag) {
+				SystemTime::now()
+					.duration_since(UNIX_EPOCH)?
+					.as_secs()
+					.try_into()?
+			} else {
+				git_commit.time().seconds()
+			};
 			previous_release.previous = None;
 			releases[release_index].previous = Some(Box::new(previous_release));
 			previous_release = releases[release_index].clone();
@@ -292,19 +303,21 @@ pub fn run(mut args: Opt) -> Result<()> {
 		}
 	}
 
-	// Generate changelog.
+	// Generate output.
 	let changelog = Changelog::new(releases, &config)?;
+	if args.context {
+		return changelog.write_context(&mut io::stdout());
+	}
 	if let Some(path) = args.prepend {
-		changelog.prepend(fs::read_to_string(&path)?, &mut File::create(path)?)
-	} else if let Some(path) = args.output {
+		changelog.prepend(fs::read_to_string(&path)?, &mut File::create(path)?)?;
+	}
+	if let Some(path) = args.output {
 		let mut output = File::create(path)?;
 		if args.context {
 			changelog.write_context(&mut output)
 		} else {
 			changelog.generate(&mut output)
 		}
-	} else if args.context {
-		changelog.write_context(&mut io::stdout())
 	} else {
 		changelog.generate(&mut io::stdout())
 	}
